@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 
 use strict;
-use Acme::Ref;
+use Acme::Ref qw/deref/;
 
 my $h = { yomomma => q!so fat! };
 
-print Acme::Ref::deref("$h")->{yomomma};
+print deref("$h")->{yomomma};
 
